//timer.c
#include "timer.h"

void Delay_uS(unsigned long a)
{
  int cycle = 0;
  while(1)
  {
    if(T2CNB0_bit.TF2 == 1) 
    {
      cycle++;
      T2CNB0_bit.TF2 = 0;
    }
    if(cycle > a) return;
  }
  
}

void SetPolarity(unsigned short pol)
{
  //Set poliary to clock pin
  //T2POL0 is change when T2OE0 is move from 0 to 1
  T2CNA0_bit.T2OE0  = 0;
  T2CNA0_bit.T2POL0 = pol;  
  T2CNA0_bit.T2OE0  = 1;
}

/**** TIMER0 WITHOUT INTERRUPTS ****/
void InitTimer0( void )
{
  //if T2DIV is 00 -> divide system clock to 1
  //if T2DIV is 01 -> divide system clock to 2
  //if T2DIV is 10 -> divide system clock to 4
  //if T2DIV is 11 -> divide system clock to 8  
  T2CFG0  = 0x040;    //Set T2DIV to 10 -> system clock / 4
  
  
  //set frequency 
  //Period = (10000h-0CCCCh) * 4 / Clock
  T2V0    = 0xCCCC;   //Value Register 
  T2R0    = 0xCCCC;   //Reset Register
  T2C0    = 0xFFFF;   //Compare Regiter

  //T2V0    = 0x0000;   //Value Register 
  //T2R0    = 0x0000;   //Reset Register
  //T2C0    = 0xFFFF;   //Compare Regiter

  
              
  T2CNB0  = 0x040;    //enable clock output
  T2CNA0  = 0x048;    //enable clock output and enable timer           
}


/**** TIMER0 WITH INTERRUPTS ****/
#pragma vector=3
__interrupt void Timer_Interrupt( void )
{
  //put your interrupt function here
  //if((PI3 & 0x20) == 0) LedOff();
  //else LedOn();
}

void Timer0_Init( void )
{
  /**** enable interrupts for module 3 ****/
  IIR_bit.II3 = 1;	  //Interrupt Identification Register
  IMR_bit.IM3 = 1;        //Interrupt Mask Register

  T2V0 = 0;               //Value Register
  T2C0 = 0;               //Compare Register
  
  T2CFG0  = 0x70;         //16-bit timer mode, system clock / 128
  T2V0    = 0xCCCC;       //Period = (10000h-0CCCCh)*128 / Clock

  T2CNA0_bit.TR2 = 1;      //Enable Timer/Counter 0
  T2CNA0_bit.T2POL0 = 1;   //Timer 0 overflow detector
  T2CNA0_bit.ET2 = 1;      //Enable interupts

}

void Timer0_Start( void )
{
  //enable interrupts 
  __enable_interrupt();
}

void Timer0_Stop( void )
{
  //disable interrupts
  __disable_interrupt();
}




