#include "uart.h" 
#include "lcd.h"      // only for using LCD 


/**** FUNCTIONS ****/
void InitUART()
{
  SCON0_bit.SM1   = 1;        //Set to mode 1 (10-bit asynchronous)
  SCON0_bit.REN   = 1;        //Enable receiver
  SMD0_bit.SMOD   = 1;        //Baud rate = 16 x baud clock
  PR0             = 0x3eF;    //PR0 = 2^21 * 9600 / 20 MHz (crystal)

  SCON0_bit.RI    = 0;        //Clear received character flag
  SCON0_bit.TI    = 0;        //Clear transmit character flag
}

void UartWriteChar(unsigned char ch)
{
  SBUF0 = ch;                 //load data to SBUF
  while (!SCON0_bit.TI);      //while shift all data
  SCON0_bit.TI = 0;           //clear interrupt flag
}

unsigned char UartReadChar(void)
{
  while (!SCON0_bit.RI);      //while read all data
  SCON0_bit.RI = 0;           //clear interrupt flag
  return SBUF0;               //return data from SBUF
}

unsigned char ReadCharUART0_nostop(void)
{
  if(SCON0_bit.RI)
  {
    SCON0_bit.RI = 0;
    return SBUF0;
  }
  else return 0;
}


/**** INTERRUPTS FUNCTIONS ****/
//init interrupt
void InitUartInterr(void)
{
  //disable interrupts
  __disable_interrupt();
  // Enable serial port interrupt
  SMD0_bit.ESI = 1;           
  // Serial port reciver enabled
  SCON0_bit.REN = 1;          
  // Activate the interrupt request from module 2 where SMD0 is located
  IMR_bit.IM2 = 1;           
  //enable interupts
  __enable_interrupt();
}

// serial port module vector
#pragma vector=2
// define the interrupt handler    
__interrupt void uartReceiveHandler( void )
{
  //temp variable
  unsigned char ch;
  // Clear the Recieve Interrupt Flag
  SCON0_bit.RI = 0;
  // read data value from Serial Data Buffer
  ch = SBUF0;
  
  //function that processing interupts
  //LcdWriteChar(7, ch);
  UartWriteChar(ch);
  UartWriteChar('*');
}
